@@ -58,8 +58,8 @@ OC.L10N.register(
     "Cannot copy" : "无法复制",
     "Copy link" : "复制链接",
     "Toggling of address book was not successful" : "通讯录切换不成功",
-    "This will delete the address book and every contacts within it" : "这将删除通讯录和其中的每个联系人",
-    "Delete {addressbook}?" : "删除 {addressbook} ？",
+    "This will delete the address book and every contacts within it" : "这将删除通讯录及其中的所有联系人",
+    "Delete {addressbook}?" : "删除 {addressbook}？",
     "This will unshare the address book and every contacts within it" : "这将取消共享通讯录及其中的每位联系人",
     "Unshare {addressbook}?" : "取消共享 {addressbook}？ ",
     "Deletion of address book was not successful." : "通讯录删除不成功",
@@ -181,28 +181,43 @@ OC.L10N.register(
     "Calendar events with you" : "与您分享的日历事件",
     "Deck cards with you" : "与您分享的卡片",
     "No shared items with this contact" : "与该联系人无共享项目",
-    "Move" : "Move",
+    "Add contacts to groups" : "添加联系人到群组",
+    "Move contacts to addressbook" : "移动联系人到通讯录",
+    "Select groups" : "选择群组",
+    "Select addressbook" : "选择通讯录",
+    "Selected contacts" : "已选择联系人",
+    "Please note that only {count} of the {total} contacts can be added to a group" : "请注意，{total} 位联系人中只有 {count} 位可以添加到群组中",
+    "Please note that only {count} of the {total} contacts can be moved" : "请注意，{total} 位联系人中只有 {count} 位可以移动。",
+    "This contact cannot be grouped" : "此联系人无法分组",
+    "This contact cannot be moved" : "此联系人无法移动",
+    "Move" : "移动",
+    "from {addressbook}" : "从 {addressbook}",
     "Confirm merging contacts" : "确认合并联系人",
     "The selected contacts have conflicting information. Choose which information to keep" : "所选联系人的信息存在冲突。请选择要保留的信息",
     "Contacts can be merged" : "联系人可以合并",
     "Groups" : "群组",
-    "Select groups to add the merged contact to" : "选择要添加合并联系人的组",
+    "Select groups to add the merged contact to" : "选择要添加合并联系人的群组",
     "Merge contacts" : "合并联系人",
     "_Delete {number} contact_::_Delete {number} contacts_" : ["删除 {number} 位联系人"],
     "Please select at least one editable contact to delete" : "请至少选择一个可编辑的联系人进行删除",
     "Please select two editable contacts to merge" : "请选择两个可编辑的联系人进行合并",
+    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["添加 {number} 位联系人到群组"],
+    "Please select at least one editable contact to add to a group" : "请至少选择一位可编辑的联系人以添加到群组中",
+    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["移动 {number} 位联系人到通讯录"],
+    "Please select at least one editable contact to move to an addressbook" : "请至少选择一位可编辑的联系人以移动到通讯录中",
     "Are you sure you want to proceed?" : "是否确定要继续？",
+    "Add contacts to group" : "添加联系人到群组",
     "Search contacts …" : "搜索联系人 …",
     "Unselect {number}" : "取消选择 {number}",
     "Add to {group}" : "添加到 {group}",
-    "Add members to {group}" : "将成员添加到 {group}",
+    "Add members to {group}" : "添加成员到 {group}",
     "Please note that you can only add contacts from writable address books to contact groups. Contacts from read-only address books, such as the system address book, cannot be added." : "请注意，您只能将可写通讯录中的联系人添加到联系人组。无法添加只读通讯录（如系统通讯录）中的联系人。",
     "Remove {type}" : "移除 {type}",
     "Add to group" : "添加到群组",
-    "Add members to group" : "将成员添加到组",
+    "Add members to group" : "添加成员到群组",
     "Search {types}" : "搜索 {types}",
     "Add guest" : "添加访客",
-    "Search for people to add" : "搜索要添加的人",
+    "Search for people to add" : "搜索要添加的联系人",
     "No results" : "无结果",
     "Add {type}" : "添加  {type}",
     "New team name" : "新团队名称",
@@ -222,7 +237,7 @@ OC.L10N.register(
     "Accept membership request" : "接受成员身份请求",
     "Reject membership request" : "拒绝成员身份请求",
     "Manage level" : "管理级别",
-    "Remove member" : "删除成员",
+    "Remove member" : "移除成员",
     "Unable to get the results" : "无法获得结果",
     "Some members could not be added" : "无法添加一些成员",
     "There was an issue adding members to the team" : "向团队添加成员时出现问题",
@@ -355,7 +370,7 @@ OC.L10N.register(
     "Unknown" : "未知",
     "Time zone" : "时区",
     "Spoken languages" : "口语",
-    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
+    "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 位联系人无法读取"],
     "An error has occurred in team(s). Check the console for more details." : "团队中出现错误。有关更多详情，请查看控制台。",
     "Unable to create team {circleName}" : "无法创建团队 {circleName}",
     "Unable to delete team {circleId}" : "无法删除团队 {circleId}",
