@@ -181,7 +181,17 @@ OC.L10N.register(
     "Calendar events with you" : "有您的日曆事件",
     "Deck cards with you" : "有您的 Deck 卡片",
     "No shared items with this contact" : "沒有與該聯絡人分享的項目",
+    "Add contacts to groups" : "新增聯絡人到群組",
+    "Move contacts to addressbook" : "將聯絡人移動到通訊錄",
+    "Select groups" : "選取群組",
+    "Select addressbook" : "選取通訊錄",
+    "Selected contacts" : "已選取聯絡人",
+    "Please note that only {count} of the {total} contacts can be added to a group" : "請注意：在 {total} 個聯絡人中，僅能新增 {count} 個至群組",
+    "Please note that only {count} of the {total} contacts can be moved" : "請注意：在 {total} 個聯絡人中，僅能移動 {count} 個聯絡人",
+    "This contact cannot be grouped" : "此聯絡人無法加入群組",
+    "This contact cannot be moved" : "此聯絡人無法移動",
     "Move" : "Move",
+    "from {addressbook}" : "來自 {addressbook}",
     "Confirm merging contacts" : "確認合併聯絡人",
     "The selected contacts have conflicting information. Choose which information to keep" : "選定的聯絡人有互相衝突的資訊。請選擇要保留的資訊",
     "Contacts can be merged" : "可以合併聯絡人",
@@ -191,7 +201,12 @@ OC.L10N.register(
     "_Delete {number} contact_::_Delete {number} contacts_" : ["刪除 {number} 個聯絡人"],
     "Please select at least one editable contact to delete" : "請選取至少一個可編輯的聯絡人來刪除",
     "Please select two editable contacts to merge" : "請選取兩個可編輯的聯絡人進行合併",
+    "_Add {number} contact to group_::_Add {number} contacts to group_" : ["新增 {number} 個聯絡人至群組"],
+    "Please select at least one editable contact to add to a group" : "請選取至少一個可編輯的聯絡人以新增至群組",
+    "_Move {number} contact to addressbook_::_Move {number} contacts to addressbook_" : ["將 {number} 個聯絡人移動至通訊錄"],
+    "Please select at least one editable contact to move to an addressbook" : "請選取至少一個可編輯的聯絡人以移動至通訊錄",
     "Are you sure you want to proceed?" : "您想要繼續嗎？",
+    "Add contacts to group" : "新增聯絡人至群組",
     "Search contacts …" : "搜尋聯絡人……",
     "Unselect {number}" : "取消選取 {number}",
     "Add to {group}" : "新增至 {group}",
